calculate_nd_scalar_derivatives — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# calculate_nd_scalar_derivatives

static ElectronicBandStructure.calculate_nd_scalar_derivatives(scalar_array, reciprocal_lattice)
  Transforms the derivatives to cartesian coordinates

    (n,j,k,…)->(n,j,k,…,3)

  Parameters:

    - derivatives (np.ndarray) – The derivatives to transform

    - reciprocal_lattice (np.ndarray) – The reciprocal lattice

  Returns:

    np.ndarray – The transformed derivatives